Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(56)

Unified Diff: chrome/browser/extensions/component_loader.cc

Issue 10086011: [Chrome OS ECHO]: Rename API and method names (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: address tbarzic's comments Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/component_loader.cc
diff --git a/chrome/browser/extensions/component_loader.cc b/chrome/browser/extensions/component_loader.cc
index 1fc05ce3559024c794aca7fe187c4b3984413996..a8723f41e3f3007cc5d556536cf6b41ad77f81c5 100644
--- a/chrome/browser/extensions/component_loader.cc
+++ b/chrome/browser/extensions/component_loader.cc
@@ -295,14 +295,14 @@ void ComponentLoader::AddDefaultComponentExtensions() {
FilePath(FILE_PATH_LITERAL("/usr/share/chromeos-assets/gaia_auth")));
}
- // TODO(gauravsh): Only include offers extension on official builds.
- FilePath offers_extension_path(FILE_PATH_LITERAL(
- "/usr/share/chromeos-assets/offers"));
- if (command_line->HasSwitch(switches::kOffersExtensionPath)) {
- offers_extension_path =
- command_line->GetSwitchValuePath(switches::kOffersExtensionPath);
+ // TODO(gauravsh): Only include echo extension on official builds.
+ FilePath echo_extension_path(FILE_PATH_LITERAL(
+ "/usr/share/chromeos-assets/echo"));
+ if (command_line->HasSwitch(switches::kEchoExtensionPath)) {
+ echo_extension_path =
+ command_line->GetSwitchValuePath(switches::kEchoExtensionPath);
}
- Add(IDR_OFFERS_MANIFEST, offers_extension_path);
+ Add(IDR_ECHO_MANIFEST, echo_extension_path);
#if defined(OFFICIAL_BUILD)
if (browser_defaults::enable_help_app) {
« no previous file with comments | « chrome/browser/chromeos/system/statistics_provider.cc ('k') | chrome/browser/extensions/extension_function_registry.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698